﻿using System;

namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Потоки агрегированных стаканов, отличающиеся глубиной.
	/// Для фьючерсов:
	/// FORTS_FUTAGGR50_REPL – стакан глубиной 50 котировок
	/// FORTS_FUTAGGR20_REPL – стакан глубиной 20 котировок
	/// FORTS_FUTAGGR5_REPL – стакан глубиной 5 котировок
	/// Для опционов:
	/// FORTS_OPTAGGR50_REPL – стакан глубиной 50 котировок
	/// FORTS_OPTAGGR20_REPL – стакан глубиной 20 котировок
	/// FORTS_OPTAGGR5_REPL – стакан глубиной 5 котировок
	/// Таблица: orders_aggr - Агрегированные стаканы.
	/// </summary>
	public class PlazaAggregationColumns : PlazaColumns
	{
		internal PlazaAggregationColumns(PlazaTableId tableId)
			: base(tableId)
		{
			IsinId = new PlazaColumn(tableId, "isin_id", typeof(int));
			Price = new PlazaColumn(tableId, "price", "d16.5");
			Volume = new PlazaColumn(tableId, "volume", typeof(long));
			Moment = new PlazaColumn(tableId, "moment", typeof(DateTime)/*, false*/); // Pyhta4og: форсировать получения moment в стаканах
			Direction = new PlazaColumn(tableId, "dir", typeof(bool));
		}

		/// <summary>
		/// Уникальный числовой идентификатор инструмента.
		/// </summary>
		public readonly PlazaColumn IsinId;

		/// <summary>
		/// Цена котировки.
		/// </summary>
		public readonly PlazaColumn Price;

		/// <summary>
		/// Объем агрегированной котировки.
		/// </summary>
		public readonly PlazaColumn Volume;

		/// <summary>
		/// Время последнего обновления котировки.
		/// </summary>
		public readonly PlazaColumn Moment;

		/// <summary>
		/// Направление котировки. // 1 - покупка, 2 - продажа
		/// </summary>
		public readonly PlazaColumn Direction;
	}
}