﻿using System;

namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Поток FORTS_FUTINFO_REPL - Фьючерсы: справочная и сессионная информация.
	/// Таблица fut_bond_registry: Справочник параметров облигаций.
	/// </summary>
	public class PlazaBondRegistryFutureColumns : PlazaColumns
	{
		internal PlazaBondRegistryFutureColumns()
			: base(PlazaTableId.BondRegistryFuture)
		{
			BondId = new PlazaColumn(TableId, "bond_id", typeof(int));
			SmallName = new PlazaColumn(TableId, "small_name", "c25");
			ShortIsin = new PlazaColumn(TableId, "short_isin", "c25");
			Name = new PlazaColumn(TableId, "name", "c75");
			DateRedempt = new PlazaColumn(TableId, "date_redempt", typeof(DateTime));
			Nominal = new PlazaColumn(TableId, "nominal", "d16.5");
			BondType = new PlazaColumn(TableId, "bond_type", typeof(bool));
			YearBase = new PlazaColumn(TableId, "year_base", typeof(short));
		}

		/// <summary>
		/// Цифровой код облигации.
		/// </summary>
		public readonly PlazaColumn BondId;

		/// <summary>
		/// Торговый код в корпоративных торгах РТС.
		/// </summary>
		public readonly PlazaColumn SmallName;

		/// <summary>
		/// Выпуск облигации.
		/// </summary>
		public readonly PlazaColumn ShortIsin;

		/// <summary>
		/// Наименование облигации.
		/// </summary>
		public readonly PlazaColumn Name;

		/// <summary>
		/// Дата погашения облигации.
		/// </summary>
		public readonly PlazaColumn DateRedempt;

		/// <summary>
		/// Номинал облигации.
		/// </summary>
		public readonly PlazaColumn Nominal;

		/// <summary>
		/// Тип: акция/облигация.
		/// </summary>
		public readonly PlazaColumn BondType;

		/// <summary>
		/// База года.
		/// </summary>
		public readonly PlazaColumn YearBase;
	}
}