﻿using System;

namespace StockSharp.Plaza.Metadata
{
    /// <summary>
    /// Поток FORTS_INFO_REPL - Дополнительная справочная информация.
    /// Таблица futures_params - Параметры фьючерсов.
    /// </summary>
    public class PlazaFuturesParamsColumns : PlazaColumns
    {
        internal PlazaFuturesParamsColumns()
            : base(PlazaTableId.FuturesParams)
        {
            Isin = new PlazaColumn(TableId, "isin", "c25");
            IsinId = new PlazaColumn(TableId, "isin_id", typeof(int));
            CodeVCB = new PlazaColumn(TableId, "code_vcb", "c25");
            Limit = new PlazaColumn(TableId, "limit", typeof(double));
            SettlPrice = new PlazaColumn(TableId, "settl_price", "d16.5");
            SpreadAspect = new PlazaColumn(TableId, "spread_aspect", typeof(byte));
            Subrisk = new PlazaColumn(TableId, "subrisk", typeof(byte));
            StepPrice = new PlazaColumn(TableId, "step_price", typeof(double));
            BaseGO = new PlazaColumn(TableId, "base_go", "d26.2");
            ExpDate = new PlazaColumn(TableId, "exp_date", typeof(DateTime));
            SpotSigns = new PlazaColumn(TableId, "spot_signs", typeof(byte));
            SettlPriceReal = new PlazaColumn(TableId, "settl_price_real", "d16.5");
            MinStep = new PlazaColumn(TableId, "min_step", typeof(double));
        }

        /// <summary>
        /// Идентификатор инструмента.
        /// </summary>
        public readonly PlazaColumn Isin;

        /// <summary>
        /// Уникальный числовой идентификатор инструмента.
        /// </summary>
        public readonly PlazaColumn IsinId;

        /// <summary>
        /// Код базового контракта.
        /// </summary>
        public readonly PlazaColumn CodeVCB;

        /// <summary>
        /// Лимит колебания цены контракта.
        /// </summary>
        public readonly PlazaColumn Limit;

        /// <summary>
        /// Расчетная цена.
        /// </summary>
        public readonly PlazaColumn SettlPrice;

        /// <summary>
        /// Признак вхождения в спрэд.
        /// </summary>
        public readonly PlazaColumn SpreadAspect;

        /// <summary>
        /// Признак учета рисков по подточкам риска.
        /// </summary>
        public readonly PlazaColumn Subrisk;

        /// <summary>
        /// Цена минимального шага.
        /// </summary>
        public readonly PlazaColumn StepPrice;

        /// <summary>
        /// Базовое ГО.
        /// </summary>
        public readonly PlazaColumn BaseGO;

        /// <summary>
        /// Дата экспирации.
        /// </summary>
        public readonly PlazaColumn ExpDate;

        /// <summary>
        /// Признак спот-фьючерса.
        /// </summary>
        public readonly PlazaColumn SpotSigns;

        /// <summary>
        /// Реальная расчетная цена фьючерса.
        /// </summary>
        public readonly PlazaColumn SettlPriceReal;

        /// <summary>
        /// Минимальный шаг изменения цены.
        /// </summary>
        public readonly PlazaColumn MinStep;

    }
}