﻿namespace StockSharp.Plaza.Metadata
{
	using System;

	/// <summary>
	/// Колонки таблицы, содержащей информацию о заявках.
	/// </summary>
	public abstract class PlazaOrdersDerivativeColumns : PlazaColumns
	{
		internal PlazaOrdersDerivativeColumns(PlazaTableId tableId)
			: base(tableId)
		{
			OrderId = new PlazaColumn(TableId, "id_ord", typeof(long));
			SessionId = new PlazaColumn(TableId, "sess_id", typeof(int));
			ClientCode = new PlazaColumn(TableId, "client_code", "c7");
			Moment = new PlazaColumn(TableId, "moment", typeof(DateTime));
			Status = new PlazaColumn(TableId, "status", typeof(int));
			Action = new PlazaColumn(TableId, "action", "i1");
			IsinId = new PlazaColumn(TableId, "isin_id", typeof(int));
			Direction = new PlazaColumn(TableId, "dir", typeof(bool));
			Price = new PlazaColumn(TableId, "price", "d16.5");
			AmountOperation = new PlazaColumn(TableId, "amount", typeof(int));
			AmountRest = new PlazaColumn(TableId, "amount_rest", typeof(int));
			Comment = new PlazaColumn(TableId, "comment", "c20");
			Hedge = new PlazaColumn(TableId, "hedge", typeof(bool));
			Trust = new PlazaColumn(TableId, "trust", typeof(bool));
			ExtId = new PlazaColumn(TableId, "ext_id", typeof(int));
			LoginFrom = new PlazaColumn(TableId, "login_from", "c20");
			BrokerTo = new PlazaColumn(TableId, "broker_to", "c7");
			BrokerToRTS = new PlazaColumn(TableId, "broker_to_rts", "c7");
			DateOrderExpiration = new PlazaColumn(TableId, "date_exp", typeof(DateTime));
			OrderId1 = new PlazaColumn(TableId, "id_ord1", typeof(long));
			BrokerFromRTS = new PlazaColumn(TableId, "broker_from_rts", "c7");
		}

		/// <summary>
		/// Номер заявки.
		/// </summary>
		public readonly PlazaColumn OrderId;

		/// <summary>
		/// Идентификатор торговой сессии.
		/// </summary>
		public readonly PlazaColumn SessionId;

		/// <summary>
		/// Код клиента.
		/// </summary>
		public readonly PlazaColumn ClientCode;

		/// <summary>
		/// Время изменения состояния заявки.
		/// </summary>
		public readonly PlazaColumn Moment;

		/// <summary>
		/// Статус заявки.
		/// </summary>
		public readonly PlazaColumn Status;

		/// <summary>
		/// Действие с заявкой.
		/// </summary>
		public readonly PlazaColumn Action;

		/// <summary>
		/// Уникальный числовой идентификатор инструмента.
		/// </summary>
		public readonly PlazaColumn IsinId;

		/// <summary>
		/// Направление.
		/// </summary>
		public readonly PlazaColumn Direction;

		/// <summary>
		/// Цена.
		/// </summary>
		public readonly PlazaColumn Price;

		/// <summary>
		/// Количество в операции.
		/// </summary>
		public readonly PlazaColumn AmountOperation;

		/// <summary>
		/// Оставшееся количество в заявке.
		/// </summary>
		public readonly PlazaColumn AmountRest;

		/// <summary>
		/// Комментарий трейдера.
		/// </summary>
		public readonly PlazaColumn Comment;

		/// <summary>
		/// Признак хеджевой заявки.
		/// </summary>
		public readonly PlazaColumn Hedge;

		/// <summary>
		/// Признак заявки доверительного управления.
		/// </summary>
		public readonly PlazaColumn Trust;

		/// <summary>
		/// Внешний номер.
		/// </summary>
		public readonly PlazaColumn ExtId;

		/// <summary>
		/// Логин пользователя, поставившего заявку.
		/// </summary>
		public readonly PlazaColumn LoginFrom;

		/// <summary>
		/// Код FORTS фирмы-адресата внесистемной заявки.
		/// </summary>
		public readonly PlazaColumn BrokerTo;

		/// <summary>
		/// Код RTS фирмы-адресата внесистемной заявки.
		/// </summary>
		public readonly PlazaColumn BrokerToRTS;

		/// <summary>
		/// Дата истечения заявки.
		/// </summary>
		public readonly PlazaColumn DateOrderExpiration;

		/// <summary>
		/// Номер первой заявки.
		/// </summary>
		public readonly PlazaColumn OrderId1;

		/// <summary>
		/// Код РТС клиента - владельца заявки.
		/// </summary>
		public readonly PlazaColumn BrokerFromRTS;
	}
}