﻿namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Поток FORTS_POS_REPL - Информация о позициях.
	/// Таблица position - Позиции клиентов.
	/// </summary>
	public class PlazaPositionColumns : PlazaColumns
	{
		internal PlazaPositionColumns()
			: base(PlazaTableId.Positions)
		{
			IsinId = new PlazaColumn(TableId, "isin_id", typeof(int));
			ClientCode = new PlazaColumn(TableId, "client_code", "c7");
			OpenQty = new PlazaColumn(TableId, "open_qty", typeof(int));
			BuysQty = new PlazaColumn(TableId, "buys_qty", typeof(int));
			SellsQty = new PlazaColumn(TableId, "sells_qty", typeof(int));
			Pos = new PlazaColumn(TableId, "pos", typeof(int));
			NetVolumeRur = new PlazaColumn(TableId, "net_volume_rur", "d26.2");
		}

		/// <summary>
		/// Уникальный числовой идентификатор инструмента.
		/// </summary>
		public readonly PlazaColumn IsinId;

		/// <summary>
		/// Код клиента.
		/// </summary>
		public readonly PlazaColumn ClientCode;

		/// <summary>
		/// Количество позиций на начало сессии.
		/// </summary>
		public readonly PlazaColumn OpenQty;

		/// <summary>
		/// Количество купленных контрактов в ходе сессии.
		/// </summary>
		public readonly PlazaColumn BuysQty;

		/// <summary>
		/// Количество проданных контрактов в ходе сессии.
		/// </summary>
		public readonly PlazaColumn SellsQty;

		/// <summary>
		/// Текущая позиция.
		/// </summary>
		public readonly PlazaColumn Pos;

		/// <summary>
		/// Нетто-сумма денег, в рублях, на которую были совершены сделки. Положительное число - деньги приходят, отрицательное - деньги выплачиваются.
		/// </summary>
		public readonly PlazaColumn NetVolumeRur;
	}
}