﻿using System;

namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Колонки таблицы, содержащей cправочник торгуемых инструментов.
	/// Поток FORTS_OPTINFO_REPL - таблица opt_sess_contents.
	/// </summary>
	public class PlazaSessionContentsOptionColumns : PlazaSessionContentsDerivativeColumns
	{
		internal PlazaSessionContentsOptionColumns()
			: base(PlazaTableId.SessionContentsOption)
		{
			FuturesIsinId = new PlazaColumn(TableId, "fut_isin_id", typeof(int));
			BgoC = new PlazaColumn(TableId, "bgo_c", "d16.2");
			BgoNc = new PlazaColumn(TableId, "bgo_nc", "d16.2");
			IsEuropean = new PlazaColumn(TableId, "europe", typeof(bool));
			IsPut = new PlazaColumn(TableId, "put", typeof(bool));
			Strike = new PlazaColumn(TableId, "strike", "d16.5");
			ExpirationStartDate = new PlazaColumn(TableId, "d_exec_beg", typeof(DateTime));
			ExpirationEndDate = new PlazaColumn(TableId, "d_exec_end", typeof(DateTime));
			BgoBuy = new PlazaColumn(TableId, "bgo_buy", "d16.2");
			BaseIsinId = new PlazaColumn(TableId, "base_isin_id", typeof(int));
		}

		/// <summary>
		/// Код фьючерсного инструмента.
		/// </summary>
		public readonly PlazaColumn FuturesIsinId;

		/// <summary>
		/// Базовое ГО под одну покрытую позицию подписчика (руб).
		/// </summary>
		public readonly PlazaColumn BgoC;

		/// <summary>
		/// Базовое ГО под одну непокрытую позицию подписчика (руб).
		/// </summary>
		public readonly PlazaColumn BgoNc;

		/// <summary>
		/// Разновидность опциона. 0 - американский опцион, 1 - европейский опцион.
		/// </summary>
		public readonly PlazaColumn IsEuropean;

		/// <summary>
		/// Тип опциона. 0 - Call опцион, 1 - Put опцион.
		/// </summary>
		public readonly PlazaColumn IsPut;

		/// <summary>
		/// Цена страйк.
		/// </summary>
		public readonly PlazaColumn Strike;

		/// <summary>
		/// Дата начала экспирации инструмента.
		/// </summary>
		public readonly PlazaColumn ExpirationStartDate;

		/// <summary>
		/// Дата окончания экспирации инструмента.
		/// </summary>
		public readonly PlazaColumn ExpirationEndDate;

		/// <summary>
		/// Базовое ГО под покупку маржируемого опциона.
		/// </summary>
		public readonly PlazaColumn BgoBuy;

		/// <summary>
		/// Числовой идентификатор базового инструмента.
		/// </summary>
		public readonly PlazaColumn BaseIsinId;
	}
}