﻿using System;

namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Поток FORTS_FUTINFO_REPL - Фьючерсы: справочная и сессионная информация.
    /// Таблица sys_messages: Сообщения торговой системы.
	/// </summary>
	public class PlazaSysMessagesColumns : PlazaColumns
	{
        internal PlazaSysMessagesColumns()
			: base(PlazaTableId.SysMessages)
		{
            MsgId = new PlazaColumn(TableId, "msg_id", typeof(int));
            Moment = new PlazaColumn(TableId, "moment", typeof(DateTime));
            LangCode = new PlazaColumn(TableId, "lang_code", "c8");
            Urgency = new PlazaColumn(TableId, "urgency", typeof(byte));
            Status = new PlazaColumn(TableId, "status", typeof(byte));
            Text = new PlazaColumn(TableId, "text", "c255");
            CancelMoment = new PlazaColumn(TableId, "cancel_moment", typeof(DateTime));
        }

		/// <summary>
        /// Уникальный идентификатор сообщения.
		/// </summary>
		public readonly PlazaColumn MsgId;

		/// <summary>
        /// Дата и время регистрации сообщения.
		/// </summary>
		public readonly PlazaColumn Moment;

		/// <summary>
        /// Язык сообщения.
		/// </summary>
        public readonly PlazaColumn LangCode;

		/// <summary>
        /// Признак срочности сообщения.
		/// </summary>
        public readonly PlazaColumn Urgency;

		/// <summary>
        /// Статус сообщения.
		/// </summary>
        public readonly PlazaColumn Status;

		/// <summary>
        /// Текст сообщения.
		/// </summary>
        public readonly PlazaColumn Text;

		/// <summary>
        /// Время отмены сообщения.
		/// </summary>
        public readonly PlazaColumn CancelMoment;
    
    }
}