﻿namespace StockSharp.Plaza.Metadata
{
	using Ecng.Common;

	static class PlazaTableSystemName
	{
		public const string BaseContractsParams = "base_contracts_params";
		public const string BrokerParams = "broker_params";
		public const string ClientParams = "client_params";
		public const string Common = "common";
		public const string Deal = "deal";
		public const string DeliveryReport = "delivery_report";
		public const string Diler = "diler";
		public const string FutBondIsin = "fut_bond_isin";
		public const string FutBondNkd = "fut_bond_nkd";
		public const string FutBondNominal = "fut_bond_nominal";
		public const string FutBondRegistry = "fut_bond_registry";
		public const string FutInstruments = "fut_instruments";
		public const string FutInterClearingInfo = "fut_intercl_info";
		public const string FutRejectedOrders = "fut_rejected_orders";
		public const string FutSessionContents = "fut_sess_contents";
		public const string FutSessionSettlement = "fut_sess_settl";
		public const string FutVcb = "fut_vcb";
		public const string FutVm = "fut_vm";
		public const string FutParams = "futures_params";
		public const string HeartBeat = "heartbeat";
		public const string Info = "info";
		public const string Investr = "investr";
		public const string MoneyClearing = "money_clearing";
		public const string MultiLegDeal = "multileg_deal";
		public const string MultiLegDict = "multileg_dict";
		public const string MultiLegOrdersLog = "multileg_orders_log";
		public const string OptExpirationOrders = "opt_exp_orders";
		public const string OptInterClearingInfo = "opt_intercl_info";
		public const string OptRejectedOrders = "opt_rejected_orders";
		public const string OptSessionContents = "opt_sess_contents";
		public const string OptSessionSettlement = "opt_sess_settl";
		public const string OptVcb = "opt_vcb";
		public const string OptVm = "opt_vm";
		public const string OptParams = "options_params";
		public const string Orders = "orders";
		public const string OrdersAggr = "orders_aggr";
		public const string OrdersLog = "orders_log";
		public const string Portfolio = "part";
		public const string Position = "position";
		public const string Index = "rts_index";
		public const string IndexLog = "rts_index_log";
		public const string Session = "session";
		public const string SysMessages = "sys_messages";
		public const string UsdOnline = "usd_online";
		//public const string UserDeal = "user_deal";
		public const string VirtualFuturesParams = "virtual_futures_params";
		public const string Volatility = "volat";
		public const string VolatilityCoeff = "volat_coeff";
	}

	static class ReplicationStream
	{
		public const string TradeFuture = "FORTS_FUTTRADE_REPL";
		public const string TradeOption = "FORTS_OPTTRADE_REPL";
		public const string OrderBookFuture = "FORTS_FUTORDERBOOK_REPL";
		public const string OrderBookOption = "FORTS_OPTORDERBOOK_REPL";
		public const string CommonFuture = "FORTS_FUTCOMMON_REPL";
		public const string CommonOption = "FORTS_OPTCOMMON_REPL";
		public const string Position = "FORTS_POS_REPL";
		public const string Portfolio = "FORTS_PART_REPL";
		public const string InfoFuture = "FORTS_FUTINFO_REPL";
		public const string InfoOption = "FORTS_OPTINFO_REPL";
		public const string MiscInfo = "FORTS_MISCINFO_REPL";
		public const string ClearingMoney = "FORTS_CLMONEY_REPL";
		public const string Index = "RTS_INDEX_REPL";
		public const string IndexLog = "RTS_INDEXLOG_REPL";
		public const string VM = "FORTS_VM_REPL";
		public const string Volatility = "FORTS_VOLAT_REPL";
		public const string Info = "FORTS_INFO_REPL";

		public const string Aggr50Future = "FORTS_FUTAGGR50_REPL";
		public const string Aggr20Future = "FORTS_FUTAGGR20_REPL";
		public const string Aggr5Future = "FORTS_FUTAGGR5_REPL";

		public const string Aggr50Option = "FORTS_OPTAGGR50_REPL";
		public const string Aggr20Option = "FORTS_OPTAGGR20_REPL";
		public const string Aggr5Option = "FORTS_OPTAGGR5_REPL";
	}

	class PlazaTableId : Equatable<PlazaTableId>
	{
		private readonly string _name;

		static PlazaTableId()
		{
			Aggregation5Future = new PlazaTableId(ReplicationStream.Aggr5Future, PlazaTableSystemName.OrdersAggr);
			Aggregation20Future = new PlazaTableId(ReplicationStream.Aggr20Future, PlazaTableSystemName.OrdersAggr);
			Aggregation50Future = new PlazaTableId(ReplicationStream.Aggr50Future, PlazaTableSystemName.OrdersAggr);
			Aggregation5Option = new PlazaTableId(ReplicationStream.Aggr5Option, PlazaTableSystemName.OrdersAggr);
			Aggregation20Option = new PlazaTableId(ReplicationStream.Aggr20Option, PlazaTableSystemName.OrdersAggr);
			Aggregation50Option = new PlazaTableId(ReplicationStream.Aggr50Option, PlazaTableSystemName.OrdersAggr);

			HeartBeatFuture = new PlazaTableId(ReplicationStream.TradeFuture, PlazaTableSystemName.HeartBeat);
			HeartBeatOption = new PlazaTableId(ReplicationStream.TradeOption, PlazaTableSystemName.HeartBeat);

			UsdOnline = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.UsdOnline);
			VcbFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutVcb);
			VcbOption = new PlazaTableId(ReplicationStream.InfoOption, PlazaTableSystemName.OptVcb);
			VmFuture = new PlazaTableId(ReplicationStream.VM, PlazaTableSystemName.FutVm);
			VmOption = new PlazaTableId(ReplicationStream.VM, PlazaTableSystemName.OptVm);
			Volatility = new PlazaTableId(ReplicationStream.Volatility, PlazaTableSystemName.Volatility);
			VolatilitySmile = new PlazaTableId(ReplicationStream.MiscInfo, PlazaTableSystemName.VolatilityCoeff);
			ClearingMoney = new PlazaTableId(ReplicationStream.ClearingMoney, PlazaTableSystemName.MoneyClearing);
			//!!TODO
			//ClearingMoney = new PlazaTableId(ReplicationStream.ClearingResults, PlazaTableSystemName.MoneyClearing);

			BaseContractsParams = new PlazaTableId(ReplicationStream.Info, PlazaTableSystemName.BaseContractsParams);
			FuturesParams = new PlazaTableId(ReplicationStream.Info, PlazaTableSystemName.FutParams);
			VirtualFuturesParams = new PlazaTableId(ReplicationStream.Info, PlazaTableSystemName.VirtualFuturesParams);
			OptionsParams = new PlazaTableId(ReplicationStream.Info, PlazaTableSystemName.OptParams);
			BrokerParams = new PlazaTableId(ReplicationStream.Info, PlazaTableSystemName.BrokerParams);
			ClientParams = new PlazaTableId(ReplicationStream.Info, PlazaTableSystemName.ClientParams);

			BondIsinFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutBondIsin);
			BondNkdFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutBondNkd);
			BondNominalFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutBondNominal);
			BondRegistryFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutBondRegistry);

			CommonFuture = new PlazaTableId(ReplicationStream.CommonFuture, PlazaTableSystemName.Common);
			CommonOption = new PlazaTableId(ReplicationStream.CommonOption, PlazaTableSystemName.Common);
			DealFuture = new PlazaTableId(ReplicationStream.TradeFuture, PlazaTableSystemName.Deal);
			DealOption = new PlazaTableId(ReplicationStream.TradeOption, PlazaTableSystemName.Deal);
			DeliveryReportFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.DeliveryReport);
			ExpirationOrdersOption = new PlazaTableId(ReplicationStream.InfoOption, PlazaTableSystemName.OptExpirationOrders);
			RtsIndex = new PlazaTableId(ReplicationStream.Index, PlazaTableSystemName.Index);
			RtsIndexLog = new PlazaTableId(ReplicationStream.IndexLog, PlazaTableSystemName.IndexLog);
			InterClearingInfoFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutInterClearingInfo);
			InterClearingInfoOption = new PlazaTableId(ReplicationStream.InfoOption, PlazaTableSystemName.OptInterClearingInfo);

			MultiLegDealFuture = new PlazaTableId(ReplicationStream.TradeFuture, PlazaTableSystemName.MultiLegDeal);
			MultiLegOrdersLogFuture = new PlazaTableId(ReplicationStream.TradeFuture, PlazaTableSystemName.MultiLegOrdersLog);
			MultiLegFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.MultiLegDict);
			OrderBookInfoFuture = new PlazaTableId(ReplicationStream.OrderBookFuture, PlazaTableSystemName.Info);
			OrderBookInfoOption = new PlazaTableId(ReplicationStream.OrderBookOption, PlazaTableSystemName.Info);
			OrderBookOrdersFuture = new PlazaTableId(ReplicationStream.OrderBookFuture, PlazaTableSystemName.Orders);
			OrderBookOrdersOption = new PlazaTableId(ReplicationStream.OrderBookOption, PlazaTableSystemName.Orders);
			OrdersLogFuture = new PlazaTableId(ReplicationStream.TradeFuture, PlazaTableSystemName.OrdersLog);
			OrdersLogOption = new PlazaTableId(ReplicationStream.TradeOption, PlazaTableSystemName.OrdersLog);
			Portfolios = new PlazaTableId(ReplicationStream.Portfolio, PlazaTableSystemName.Portfolio);
			Positions = new PlazaTableId(ReplicationStream.Position, PlazaTableSystemName.Position);
			RejectedOrdersFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutRejectedOrders);
			RejectedOrdersOption = new PlazaTableId(ReplicationStream.InfoOption, PlazaTableSystemName.OptRejectedOrders);
			SessionContentsFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutSessionContents);
			SessionContentsOption = new PlazaTableId(ReplicationStream.InfoOption, PlazaTableSystemName.OptSessionContents);
			SessionFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.Session);
			SessionSettlementOption = new PlazaTableId(ReplicationStream.InfoOption, PlazaTableSystemName.OptSessionSettlement);
			SessionSettlementFuture = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutSessionSettlement);
			SysMessages = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.SysMessages);
			Diler = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.Diler);
			Investr = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.Investr);
			FutInstruments = new PlazaTableId(ReplicationStream.InfoFuture, PlazaTableSystemName.FutInstruments);
		}

		private PlazaTableId(string streamName, string tableName)
		{
			StreamName = streamName;
			TableName = tableName;

			_name = StreamName + "\\" + TableName;
		}

		public string StreamName { get; private set; }
		public string TableName { get; private set; }

		public static PlazaTableId Aggregation5Future { get; private set; }
		public static PlazaTableId Aggregation20Future { get; private set; }
		public static PlazaTableId Aggregation50Future { get; private set; }
		public static PlazaTableId Aggregation5Option { get; private set; }
		public static PlazaTableId Aggregation20Option { get; private set; }
		public static PlazaTableId Aggregation50Option { get; private set; }

		public static PlazaTableId HeartBeatFuture { get; private set; }
		public static PlazaTableId HeartBeatOption { get; private set; }

		public static PlazaTableId UsdOnline { get; private set; }
		public static PlazaTableId VcbFuture { get; private set; }
		public static PlazaTableId VcbOption { get; private set; }
		public static PlazaTableId VmFuture { get; private set; }
		public static PlazaTableId VmOption { get; private set; }
		public static PlazaTableId Volatility { get; private set; }
		public static PlazaTableId VolatilitySmile { get; private set; }
		public static PlazaTableId ClearingMoney { get; private set; }

		public static PlazaTableId BaseContractsParams { get; private set; }
		public static PlazaTableId FuturesParams { get; private set; }
		public static PlazaTableId VirtualFuturesParams { get; private set; }
		public static PlazaTableId OptionsParams { get; private set; }
		public static PlazaTableId BrokerParams { get; private set; }
		public static PlazaTableId ClientParams { get; private set; }

		public static PlazaTableId BondIsinFuture { get; private set; }
		public static PlazaTableId BondNkdFuture { get; private set; }
		public static PlazaTableId BondNominalFuture { get; private set; }
		public static PlazaTableId BondRegistryFuture { get; private set; }

		public static PlazaTableId CommonFuture { get; private set; }
		public static PlazaTableId CommonOption { get; private set; }
		public static PlazaTableId DealFuture { get; private set; }
		public static PlazaTableId DealOption { get; private set; }
		public static PlazaTableId DeliveryReportFuture { get; private set; }
		public static PlazaTableId ExpirationOrdersOption { get; private set; }
		public static PlazaTableId RtsIndex { get; private set; }
		public static PlazaTableId RtsIndexLog { get; private set; }
		public static PlazaTableId InterClearingInfoFuture { get; private set; }
		public static PlazaTableId InterClearingInfoOption { get; private set; }
		public static PlazaTableId MultiLegFuture { get; private set; }
		public static PlazaTableId MultiLegDealFuture { get; private set; }
		public static PlazaTableId MultiLegOrdersLogFuture { get; private set; }
		public static PlazaTableId OrderBookInfoFuture { get; private set; }
		public static PlazaTableId OrderBookInfoOption { get; private set; }
		public static PlazaTableId OrderBookOrdersFuture { get; private set; }
		public static PlazaTableId OrderBookOrdersOption { get; private set; }
		public static PlazaTableId OrdersLogFuture { get; private set; }
		public static PlazaTableId OrdersLogOption { get; private set; }
		public static PlazaTableId Portfolios { get; private set; }
		public static PlazaTableId Positions { get; private set; }
		public static PlazaTableId RejectedOrdersFuture { get; private set; }
		public static PlazaTableId RejectedOrdersOption { get; private set; }
		public static PlazaTableId SessionContentsFuture { get; private set; }
		public static PlazaTableId SessionContentsOption { get; private set; }
		public static PlazaTableId SessionFuture { get; private set; }
		public static PlazaTableId SessionSettlementOption { get; private set; }
		public static PlazaTableId SessionSettlementFuture { get; private set; }
		public static PlazaTableId SysMessages { get; private set; }
		public static PlazaTableId Diler { get; private set; }
		public static PlazaTableId Investr { get; private set; }
		public static PlazaTableId FutInstruments { get; private set; }

		public override string ToString()
		{
			return _name;
		}

		public override int GetHashCode()
		{
			return _name.GetHashCode();
		}

		public override PlazaTableId Clone()
		{
			return new PlazaTableId(StreamName, TableName);
		}

		protected override bool OnEquals(PlazaTableId other)
		{
			return _name == other._name;
		}
	}
}