﻿namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Колонки таблицы, содержащей справочник базовых контрактов для инструментов.
	/// </summary>
	public abstract class PlazaVcbDerivativeColumns : PlazaColumns
	{
		internal PlazaVcbDerivativeColumns(PlazaTableId tableId)
			: base(tableId)
		{
			CodeVcb = new PlazaColumn(TableId, "code_vcb", "c25");
			Name = new PlazaColumn(TableId, "name", "c75");
			ExecType = new PlazaColumn(TableId, "exec_type", "c1");
			Curr = new PlazaColumn(TableId, "curr", "c3");
			ExchPay = new PlazaColumn(TableId, "exch_pay", "d16.2");
			ExchPayScalped = new PlazaColumn(TableId, "exch_pay_scalped", typeof(bool));
			ClearPay = new PlazaColumn(TableId, "clear_pay", "d16.2");
			ClearPayScalped = new PlazaColumn(TableId, "clear_pay_scalped", typeof(bool));
			TradeScheme = new PlazaColumn(TableId, "trade_scheme", "c1");
			ClientCode = new PlazaColumn(TableId, "client_code", "c7");
		}

		/// <summary>
		/// Код базового актива.
		/// </summary>
		public readonly PlazaColumn CodeVcb;

		/// <summary>
		/// Наименование.
		/// </summary>
		public readonly PlazaColumn Name;

		/// <summary>
		/// Тип исполнения.
		/// </summary>
		public readonly PlazaColumn ExecType;

		/// <summary>
		/// Валюта платежа.
		/// </summary>
		public readonly PlazaColumn Curr;

		/// <summary>
		/// Биржевой сбор за 1 контракт в рублях.
		/// </summary>
		public readonly PlazaColumn ExchPay;

		/// <summary>
		/// Признак скальпирования биржевого сбора.
		/// </summary>
		public readonly PlazaColumn ExchPayScalped;

		/// <summary>
		/// Клиринговый сбор за 1 контракт в рублях.
		/// </summary>
		public readonly PlazaColumn ClearPay;

		/// <summary>
		/// Признак скальпирования клирингового сбора.
		/// </summary>
		public readonly PlazaColumn ClearPayScalped;

		/// <summary>
		/// Форма торгов.
		/// </summary>
		public readonly PlazaColumn TradeScheme;

		/// <summary>
		/// Код клиента.
		/// </summary>
		public readonly PlazaColumn ClientCode;
	}
}