﻿using System;

namespace StockSharp.Plaza.Metadata
{
    /// <summary>
    /// Поток FORTS_INFO_REPL - Дополнительная справочная информация.
    /// Таблица virtual_futures_params - Параметры виртуальных фьючерсов.
    /// </summary>
    public class PlazaVirtualFuturesParamsColumns : PlazaColumns
    {
        internal PlazaVirtualFuturesParamsColumns()
            : base(PlazaTableId.VirtualFuturesParams)
        {
            Isin = new PlazaColumn(TableId, "isin", "c25");
            IsinBase = new PlazaColumn(TableId, "isin_base", "c25");
            IsNetPositive = new PlazaColumn(TableId, "is_net_positive", typeof(byte));
            VolatRange = new PlazaColumn(TableId, "volat_range", typeof(double));
            TSquared = new PlazaColumn(TableId, "t_squared", typeof(double));
            MaxAddRisk = new PlazaColumn(TableId, "max_addrisk", typeof(double));
            A = new PlazaColumn(TableId, "a", typeof(double));
            B = new PlazaColumn(TableId, "b", typeof(double));
            C = new PlazaColumn(TableId, "c", typeof(double));
            D = new PlazaColumn(TableId, "d", typeof(double));
            E = new PlazaColumn(TableId, "e", typeof(double));
            S = new PlazaColumn(TableId, "s", typeof(double));
            ExpDate = new PlazaColumn(TableId, "exp_date", typeof(DateTime));
            FutType = new PlazaColumn(TableId, "fut_type", typeof(byte));
            UseNullVolat = new PlazaColumn(TableId, "use_null_volat", typeof(byte));
        }

        /// <summary>
        /// Идентификатор инструмента.
        /// </summary>
        public readonly PlazaColumn Isin;

        /// <summary>
        /// Код реального фьючерса.
        /// </summary>
        public readonly PlazaColumn IsinBase;

        /// <summary>
        /// Признак учета положительных рисков по данному виртуальному фьючерсу.
        /// </summary>
        public readonly PlazaColumn IsNetPositive;

        /// <summary>
        /// Коридор волатильности.
        /// </summary>
        public readonly PlazaColumn VolatRange;

        /// <summary>
        /// Величина квадратного корня из времени до экспирации опционов на данный виртуальный фьючерс.
        /// </summary>
        public readonly PlazaColumn TSquared;

        /// <summary>
        /// Ограничение сверху на дополнительные риски.
        /// </summary>
        public readonly PlazaColumn MaxAddRisk;

        /// <summary>
        /// A.
        /// </summary>
        public readonly PlazaColumn A;

        /// <summary>
        /// B.
        /// </summary>
        public readonly PlazaColumn B;

        /// <summary>
        /// C.
        /// </summary>
        public readonly PlazaColumn C;

        /// <summary>
        /// D.
        /// </summary>
        public readonly PlazaColumn D;

        /// <summary>
        /// E.
        /// </summary>
        public readonly PlazaColumn E;

        /// <summary>
        /// S.
        /// </summary>
        public readonly PlazaColumn S;

        /// <summary>
        /// Дата экспирации.
        /// </summary>
        public readonly PlazaColumn ExpDate;

        /// <summary>
        /// Признак маржинальной системы расчетов для опционов, привязанных к данному ВФ.
        /// </summary>
        public readonly PlazaColumn FutType;

        /// <summary>
        /// Признак нулевой волатильности.
        /// </summary>
        public readonly PlazaColumn UseNullVolat;

    }
}