﻿namespace StockSharp.Plaza
{
	using System;
	using System.Runtime.InteropServices;

	using Ecng.Common;

	/// <summary>
	/// Исключение, содержащее код и описание ошибки, полученной от Plaza.
	/// </summary>
	public class PlazaException : ApplicationException
	{
		internal PlazaException(string message, COMException exception)
			: base(FormatErrorText(message, exception.ErrorCode, exception.GetErrorText()), exception)
		{
			ErrorCode = exception.ErrorCode;
		}

		/// <summary>
		/// Создать <see cref="PlazaException"/>.
		/// </summary>
		/// <param name="errorCode">Код ошибки, которую прислала Plaza.</param>
		/// <param name="errorText">Описание ошибки.</param>
		internal PlazaException(int errorCode, string errorText)
			: base(FormatErrorText("Произошла ошибка.", errorCode, errorText))
		{
			ErrorCode = errorCode;
		}

		/// <summary>
		/// Код ошибки, которую прислала Plaza.
		/// </summary>
		public int ErrorCode { get; private set; }

		private static string FormatErrorText(string message, int errorCode, string errorText)
		{
			if (message.IsEmpty())
				throw new ArgumentNullException("message");

			return "{0} Код {1}, описание '{2}'.".Put(message, errorCode, errorText);
		}
	}
}