﻿namespace StockSharp.Plaza
{
	using System;
	using System.Linq;

	using Ecng.Collections;

	using StockSharp.BusinessEntities;
	using StockSharp.Plaza.Metadata;

	class PlazaOrderBuilder
	{
		private sealed class OrderInfo
		{
			public OrderInfo(Security security, PlazaOrdersDerivativeColumns metadata)
			{
				Security = security;
				Metadata = metadata;

				//Records = new SynchronizedList<PlazaRecord>();
			}

			public Security Security { get; private set; }
			public PlazaOrdersDerivativeColumns Metadata { get; private set; }

			//public SynchronizedList<PlazaRecord> Records { get; private set; }

			public PlazaRecord FirstRecord { get; private set; }
			public PlazaRecord LastRecord { get; private set; }

			public void AddRecord(PlazaRecord record)
			{
				if (record == null)
					throw new ArgumentNullException("record");

				LastRecord = record;

				if (FirstRecord == null)
					FirstRecord = LastRecord;
			}
		}

		private readonly SynchronizedDictionary<PlazaStream, SynchronizedDictionary<long, OrderInfo>> _info = new SynchronizedDictionary<PlazaStream, SynchronizedDictionary<long, OrderInfo>>();

		public PlazaOrderBuilder(PlazaTrader trader)
		{
            _info.SafeAdd(trader.StreamRegistry.OrdersLogOptionStream);
            _info.SafeAdd(trader.StreamRegistry.OrdersLogFutureStream);
		}

		public void AddOrderInfo(PlazaStream stream, Security security, PlazaOrdersDerivativeColumns metadata, PlazaRecord record)
		{
			_info[stream].SafeAdd(record.Get<long>(metadata.OrderId), key => new OrderInfo(security, metadata)).AddRecord(record.Clone());
		}

		public void ClearChanges(PlazaStream stream)
		{
			_info[stream].Clear();
		}

		public void FlushChanges(PlazaStream stream, Action<Security, PlazaOrdersDerivativeColumns, PlazaRecord, PlazaRecord> handler)
		{
			var infos = _info[stream].SyncGet(d =>
			{
				var retVal = d.Values.ToArray();
				d.Clear();
				return retVal;
			});

			infos.ForEach(i => handler(i.Security, i.Metadata, i.FirstRecord, i.LastRecord));
		}
	}
}