﻿namespace StockSharp.Plaza
{
	using System;

	using Ecng.Collections;

	/// <summary>
	/// Коллекция потоков данных.
	/// </summary>
	public class PlazaStreamList : SynchronizedCollection<PlazaStream>
	{
		private readonly PlazaStreamManager _manager;

		internal PlazaStreamList(PlazaStreamManager manager)
		{
			if (manager == null)
				throw new ArgumentNullException("manager");

			_manager = manager;
		}

		/// <summary>
		/// Добавление потока в список.
		/// </summary>
		/// <param name="stream">Поток данных.</param>
		protected override void OnAdding(PlazaStream stream)
		{
			CheckExportStarted();
			base.OnAdding(stream);
		}

		/// <summary>
		/// Вставка по индеку потока в список.
		/// </summary>
		/// <param name="index">Индекс.</param>
		/// <param name="stream">Поток данных.</param>
		protected override void OnInserting(int index, PlazaStream stream)
		{
			CheckExportStarted();
			base.OnInserting(index, stream);
		}

		/// <summary>
		/// Удаление потока из списка.
		/// </summary>
		/// <param name="stream">Поток данных.</param>
		protected override void OnRemoving(PlazaStream stream)
		{
			CheckExportStarted();

			base.OnRemoving(stream);

			// см. комментарий перед объявлением класса
			//stream.Dispose();
			//_manager._streamsToClose.SyncDo(c =>
			//{
			//    stream.State = PlazaStreamStates.Closing;
			//    c.Add(stream);
			//});
		}

		/// <summary>
		/// Очищение списка.
		/// </summary>
		protected override void OnClearing()
		{
			foreach (var stream in ToArray())
				Remove(stream);
		}

		private void CheckExportStarted()
		{
			if (_manager.IsExportStarted)
				throw new InvalidOperationException("Нельзя менять коллекцию потоков при запущенном экспорте.");
		}
	}
}