﻿namespace StockSharp.Plaza.Wrappers
{
	/// <summary>
	/// Работа с клиентской схемой репликации. 
	/// </summary>
	interface ITableSetWrapper
	{
		/// <summary>
		/// Инициализация объекта и загрузка из ini-файла клиентской схемы репликации.
		/// </summary>
		/// <param name="cfgName">Файл, содержащий клиентские схемы репликации.</param>
		/// <param name="replScheme">Имя клиентской схемы репликации.</param>
		void Init(string cfgName, string replScheme);

		/// <summary>
		/// Номер жизни схемы базы данных. 
		/// </summary>
		int LifeNum { get; set; }

		/// <summary>
		/// Сохранение номера жизни схемы в ини файле.
		/// </summary>
		/// <param name="iniFileName">Файл, содержащий клиентские схемы репликации.</param>
		void UpdateLifeNumber(string iniFileName);

		/// <summary>
		/// Задать значение индетификатора изменения записи в таблице.
		/// </summary>
		/// <param name="tableName">Имя таблицы.</param>
		/// <param name="pVal">Значение.</param>
		void UpdateRevision(string tableName, long pVal);
	}

	class TableSetWrapper32 : ITableSetWrapper
	{
		internal readonly P2ClientGateMTA32.CP2TableSet TableSet;

		public TableSetWrapper32()
		{
			TableSet = new P2ClientGateMTA32.CP2TableSet();
		}

		void ITableSetWrapper.Init(string cfgName, string replScheme)
		{
			TableSet.InitFromIni2(cfgName, replScheme);
		}

		void ITableSetWrapper.UpdateLifeNumber(string iniFileName)
		{
			TableSet.SetLifeNumToIni(iniFileName);
		}

		void ITableSetWrapper.UpdateRevision(string tableName, long pVal)
		{
			TableSet.rev[tableName] = pVal;
		}

		int ITableSetWrapper.LifeNum
		{
			get { return TableSet.LifeNum; }
			set { TableSet.LifeNum = value; }
		}
	}

	class TableSetWrapper64 : ITableSetWrapper
	{
		internal readonly P2ClientGateMTA64.CP2TableSet TableSet;

		public TableSetWrapper64()
		{
			TableSet = new P2ClientGateMTA64.CP2TableSet();
		}

		void ITableSetWrapper.Init(string cfgName, string replScheme)
		{
			TableSet.InitFromIni2(cfgName, replScheme);
		}

		void ITableSetWrapper.UpdateLifeNumber(string iniFileName)
		{
			TableSet.SetLifeNumToIni(iniFileName);
		}

		void ITableSetWrapper.UpdateRevision(string tableName, long pVal)
		{
			TableSet.rev[tableName] = pVal;
		}

		int ITableSetWrapper.LifeNum
		{
			get { return TableSet.LifeNum; }
			set { TableSet.LifeNum = value; }
		}
	}
}